@@ -1,7 +1,7 @@
 /*
  * This file is part of LaTeXila.
  *
- * Copyright (C) 2014 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014-2015 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * LaTeXila is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,10 @@
  * along with LaTeXila.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/* Main header for the LaTeXila "library". Code using the library (e.g. Vala
+ * code) should #include only this header.
+ */
+
 #ifndef __LATEXILA_H__
 #define __LATEXILA_H__
 
@@ -33,6 +37,10 @@
 #include "latexila-post-processor-all-output.h"
 #include "latexila-post-processor-latex.h"
 #include "latexila-synctex.h"
+#include "latexila-templates-default.h"
+#include "latexila-templates-personal.h"
+#include "latexila-templates-dialogs.h"
+#include "latexila-templates-manage-dialog.h"
 #include "latexila-utils.h"
 
 #endif /* __LATEXILA_H__ */
